var hex2otf_8h =
[
    [ "NamePair", "structNamePair.html", null ],
    [ "DEFAULT_ID0", "hex2otf_8h.html#a59ba14cafe02ba112aa260cb17affc45", null ],
    [ "DEFAULT_ID1", "hex2otf_8h.html#a80457952fba9de3914d0f44305236ef2", null ],
    [ "DEFAULT_ID11", "hex2otf_8h.html#af3ad95ac6274edc8333dcbd3706aa603", null ],
    [ "DEFAULT_ID13", "hex2otf_8h.html#a91c55841985cdffac3f8d7d6252749dc", null ],
    [ "DEFAULT_ID14", "hex2otf_8h.html#a3a8d3619901c1776556d259d0295c6ef", null ],
    [ "DEFAULT_ID2", "hex2otf_8h.html#a02993e3b8886c3fc79e0a862582e5fd3", null ],
    [ "DEFAULT_ID5", "hex2otf_8h.html#adb78d0325526094d79149d20028f82d0", null ],
    [ "NAMEPAIR", "hex2otf_8h.html#aafa9d4317a3af734d88d6b977de27de9", null ],
    [ "UNIFONT_VERSION", "hex2otf_8h.html#a62e32863ba84411a48a0049151e68a00", null ],
    [ "NamePair", "hex2otf_8h.html#af57a7327559d80dc41d283c61c6e7063", null ],
    [ "defaultNames", "hex2otf_8h.html#a7932112a8cd522740aa941c15b79bd16", null ]
];